@@ -1,4 +1,4 @@
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 import os
 import argparse
 from rich.console import Console
@@ -309,7 +309,7 @@ def html_table(title, cols, rows, attributes):
 def main():
     # ================================================================================================
     remotetitle = "Remotes"
-    remotecolumns = ["fetch url", "remote name"]
+    remotecolumns = ["no.", "fetch url", "remote name"]
     remoterows = d.getElementsByTagName("remote")
     remoteattributes = ["fetch", "name"]
     if ishtml:
@@ -318,7 +318,7 @@ def main():
         rich_table(remotetitle, remotecolumns, remoterows, remoteattributes)
     # ================================================================================================
     inctitle = "Includes"
-    inccolumns = ["Name(xml manifest files)"]
+    inccolumns = ["no.", "Name(xml manifest files)"]
     incrows = [p.getAttribute("name") for p in d.getElementsByTagName("include")]
 
     if ishtml:
@@ -331,12 +331,12 @@ def main():
     ]
 
     rmtitle = "Removed projects"
-    rmcolumns = [f"Name ({supplier} project repos)"]
+    rmcolumns = ["no.", f"Name ({supplier} project repos)"]
     rmrows = removedprojects
-    # if ishtml:
-    #     html_table(rmtitle, rmcolumns, rmrows, emptyattributes)
-    # else:
-    #     rich_table(rmtitle, rmcolumns, rmrows, emptyattributes)
+    if ishtml:
+        html_table(rmtitle, rmcolumns, rmrows, emptyattributes)
+    else:
+        rich_table(rmtitle, rmcolumns, rmrows, emptyattributes)
     # rich_table(rmtitle, rmcolumns, rmrows, emptyattributes)
     # ================================================================================================
 
@@ -360,6 +360,7 @@ def main():
 
     reptitle = f"{company} Replaced projects with {supplier}(Modificatiosn may be small or big)"
     repcolumns = [
+        "no.",
         f"({supplier})Removed Name",
         f"({company}) Replaced Project Name",
         f"({company}) Replaced Project Path",
@@ -376,6 +377,7 @@ def main():
     # ================================================================================================
     conewtitle = f"Newly added projects with {company} package names"
     cocolumns = [
+        "no.",
         f"({company}) Project Name Tag",
         f"({company}) Project Path Tag",
         f"({company}) Project Revision",
@@ -397,6 +399,7 @@ def main():
     # ================================================================================================
     noncotitle = f"Newly added ({company} & Other Vendors) Project repos "
     noncocolumns = [
+        "no.",
         f"({company} & Other Vendors) Project Name Tag",
         f"({company} & Other Vendors) Project Path Tag",
         f"({company}) Project Revision",
@@ -419,7 +422,7 @@ def main():
     nonconewprojectsPaths = [n[1] for n in nonconewRows]
 
     allpathtitle = "All Paths for Build file processing"
-    allpathscolumns = ["Paths"]
+    allpathscolumns = ["no.", "Paths"]
     allpathsRows = actualreplacedPaths + conewprojectsPaths + nonconewprojectsPaths
     if ishtml:
         html_table(allpathtitle, allpathscolumns, allpathsRows, emptyattributes)
@@ -429,6 +432,7 @@ def main():
     newlyad_title = f"All Newly added Paths for considerations in {company}"
 
     newlyad_columns = [
+        "no.",
         f"{supplier} replaced paths",
         f"New {company} repo paths",
         f"{company} or other vendors paths",
